==> nextcloud-24.0.5.tgz: nextcloud/apps/password_policy/l10n/zh_CN.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "密码已过期，请使用忘记密码的方式重设",
    "Password must not have been used recently before." : "密码最近不能使用过。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "该密码在 100 万个最常见密码中，请选择其他密码。",
    "Password is present in compromised password list. Please choose a different password." : "该密码在禁用的密码列表中，请选择其他密码。",
    "Password needs to be at least %s characters long." : "密码最小长度需为 %s 字节",
    "Password needs to contain at least one numeric character." : "密码至少需要包含一个数字。",
    "Password needs to contain at least one special character." : "密码需要包含至少一个特殊字符。",
    "Password needs to contain at least one lower and one upper case character." : "密码至少需要包含一个小写字母和一个大写字母。",
    "Password policy" : "密码规则",
    "Allows admins to configure a password policy" : "允许管理员配置密码策略",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "允许管理员定义密码前置条件，比如说强制密码最小长度。",
    "Saved" : "已保存",
    "Minimum password length" : "最小密码长度",
    "User password history" : "用户密码记录",
    "Number of days until user password expires" : "用户密码过期前的天数",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "用户账户被锁定前的登录尝试次数（0 表示无限制）",
    "Forbid common passwords" : "禁止普通密码",
    "Enforce upper and lower case characters" : "强制要求大写和小写字符",
    "Enforce numeric characters" : "强制要求数字字符",
    "Enforce special characters" : "强制要求特殊字符",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "检查密码是否在 haveibeenpwned.com 的泄露密码列表中",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "这会创建一个密码哈希，并将此哈希的前5个字符发送到 haveibeenpwned.com 的 API，获取以这些哈希开头的所有哈希列表。然后在 Nextcloud 实例中检查此密码哈希是否在在结果集中。",
    "Unknown error" : "未知错误",
    "Minimal length has to be a non negative number" : "最小长度必须是一个非负数",
    "History size has to be a non negative number" : "历史记录大小必须是非负数 ",
    "Expiration days have to be a non negative number" : "过期天数必须是非负数 ",
    "Maximum login attempts have to be a non negative number" : "最大登录尝试次数必须是非负数"
},
"nplurals=1; plural=0;");

==> nextcloud-24.0.12.tgz: nextcloud/apps/password_policy/l10n/zh_CN.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "密码已过期，请使用忘记密码的方式重设",
    "Password must not have been used recently before." : "密码最近不能使用过。",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "该密码在 100 万个最常见密码中，请选择其他密码。",
    "Password is present in compromised password list. Please choose a different password." : "该密码在禁用的密码列表中，请选择其他密码。",
    "Password needs to be at least %s characters long." : "密码最小长度需为 %s 字节",
    "Password needs to contain at least one numeric character." : "密码至少需要包含一个数字。",
    "Password needs to contain at least one special character." : "密码需要包含至少一个特殊字符。",
    "Password needs to contain at least one lower and one upper case character." : "密码至少需要包含一个小写字母和一个大写字母。",
    "Password policy" : "密码规则",
    "Allows admins to configure a password policy" : "允许管理员配置密码策略",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "允许管理员定义密码前置条件，比如说强制密码最小长度。",
    "Minimum password length" : "最小密码长度",
    "User password history" : "用户密码记录",
    "Number of days until user password expires" : "用户密码过期前的天数",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "用户账户被锁定前的登录尝试次数（0 表示无限制）",
    "Forbid common passwords" : "禁用常见密码",
    "Enforce upper and lower case characters" : "强制要求大写和小写字符",
    "Enforce numeric characters" : "强制要求数字字符",
    "Enforce special characters" : "强制要求特殊字符",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "检查密码是否在 haveibeenpwned.com 的泄露密码列表中",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "这会创建一个密码哈希，并将此哈希的前5个字符发送到 haveibeenpwned.com 的 API，获取以这些哈希开头的所有哈希列表。然后在 Nextcloud 实例中检查此密码哈希是否在在结果集中。",
    "Unknown error" : "未知错误",
    "Minimal length has to be a non negative number" : "最小长度必须是一个非负数",
    "History size has to be a non negative number" : "历史记录大小必须是非负数 ",
    "Expiration days have to be a non negative number" : "过期天数必须是非负数 ",
    "Maximum login attempts have to be a non negative number" : "最大登录尝试次数必须是非负数",
    "Settings saved" : "已保存设置",
    "Saved" : "已保存"
},
"nplurals=1; plural=0;");
